# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

from enum import Enum

__all__ = [
    'IpAddressType',
    'LoadBalancerType',
]


class IpAddressType(str, Enum):
    IPV4 = "ipv4"
    DUALSTACK = "dualstack"


class LoadBalancerType(str, Enum):
    APPLICATION = "application"
    NETWORK = "network"
